@@ -1,7 +1,6 @@
-<?php 
+<?php
 /**
  */
-
 class Horde_Date_Parser_Locale_Pt extends Horde_Date_Parser_Locale_Base
 {
     public $definitions = array();
@@ -14,48 +13,48 @@ class Horde_Date_Parser_Locale_Pt extends Horde_Date_Parser_Locale_Base
     }
 
     /**
-    # Parses a string containing a natural language date or time. If the parser
-    # can find a date or time, either a Horde_Date or Horde_Date_Span will be returned
-    # (depending on the value of <tt>:return</tt>). If no date or time can be found,
-    # +nil+ will be returned.
-    #
-    # Options are:
-    #
-    # [<tt>:context</tt>]
-    #     <tt>:past</tt> or <tt>:future</tt> (defaults to <tt>:future</tt>)
-    #
-    #     If your string represents a birthday, you can set <tt>:context</tt> to <tt>:past</tt>
-    #     and if an ambiguous string is given, it will assume it is in the
-    #     past. Specify <tt>:future</tt> or omit to set a future context.
-    #
-    # [<tt>:now</tt>]
-    #     Time (defaults to time())
-    #
-    #     By setting <tt>:now</tt> to a Horde_Date, all computations will be based off
-    #     of that time instead of time().
-    #
-    # [<tt>:return</tt>]
-    #     'result', 'span', or 'date' (defaults to 'date')
-    #
-    #     By default, the parser will guess a single point in time for the
-    #     given date or time. If you'd rather have the entire time span returned,
-    #     set <tt>:return</tt> to 'span' and a Horde_Date_Span will be returned.
-    #     If you want the entire result, including tokens (for retrieving the text
-    #     that was or was not tagged, for example), set <tt>:return</tt> to 'result'
-    #     and you will get a result object.
-    #
-    # [<tt>:ambiguousTimeRange</tt>]
-    #     Integer or <tt>:none</tt> (defaults to <tt>6</tt> (6am-6pm))
-    #
-    #     If an Integer is given, ambiguous times (like 5:00) will be
-    #     assumed to be within the range of that time in the AM to that time
-    #     in the PM. For example, if you set it to <tt>7</tt>, then the parser will
-    #     look for the time between 7am and 7pm. In the case of 5:00, it would
-    #     assume that means 5:00pm. If <tt>:none</tt> is given, no assumption
-    #     will be made, and the first matching instance of that time will
-    #     be used.
-    */
-    
+     * Parses a string containing a natural language date or time. If the
+     * parser can find a date or time, either a Horde_Date or Horde_Date_Span
+     * will be returned (depending on the value of <tt>:return</tt>). If no
+     * date or time can be found, +nil+ will be returned.
+     *
+     * Options are:
+     *
+     * [<tt>:context</tt>]
+     *     <tt>:past</tt> or <tt>:future</tt> (defaults to <tt>:future</tt>)
+     *
+     *     If your string represents a birthday, you can set <tt>:context</tt>
+     *     to <tt>:past</tt> and if an ambiguous string is given, it will
+     *     assume it is in the past. Specify <tt>:future</tt> or omit to set a
+     *     future context.
+     *
+     * [<tt>:now</tt>]
+     *     Time (defaults to time())
+     *
+     *     By setting <tt>:now</tt> to a Horde_Date, all computations will be
+     *     based off of that time instead of time().
+     *
+     * [<tt>:return</tt>]
+     *     'result', 'span', or 'date' (defaults to 'date')
+     *
+     *     By default, the parser will guess a single point in time for the
+     *     given date or time. If you'd rather have the entire time span
+     *     returned, set <tt>:return</tt> to 'span' and a Horde_Date_Span will
+     *     be returned.  If you want the entire result, including tokens (for
+     *     retrieving the text that was or was not tagged, for example), set
+     *     <tt>:return</tt> to 'result' and you will get a result object.
+     *
+     * [<tt>:ambiguousTimeRange</tt>]
+     *     Integer or <tt>:none</tt> (defaults to <tt>6</tt> (6am-6pm))
+     *
+     *     If an Integer is given, ambiguous times (like 5:00) will be assumed
+     *     to be within the range of that time in the AM to that time in the
+     *     PM. For example, if you set it to <tt>7</tt>, then the parser will
+     *     look for the time between 7am and 7pm. In the case of 5:00, it would
+     *     assume that means 5:00pm. If <tt>:none</tt> is given, no assumption
+     *     will be made, and the first matching instance of that time will be
+     *     used.
+     */
     public function parse($text, $specifiedOptions = array())
     {
         // get options and set defaults if necessary
@@ -81,7 +80,6 @@ class Horde_Date_Parser_Locale_Pt extends Horde_Date_Parser_Locale_Base
         // store now for later =)
         $this->now = $options['now'];
 
-
 		$text = $this->normalize_special_characters($text);
 
         // put the text into a normal format to ease scanning
@@ -104,14 +102,15 @@ class Horde_Date_Parser_Locale_Pt extends Horde_Date_Parser_Locale_Base
         // strip any non-tagged tokens
         $taggedTokens = array_values(array_filter($tokens, create_function('$t', 'return $t->tagged();')));
 
-        // Remove tokens we know we don't want - for example, if the first token
-        // is a separator, drop it.
+        // Remove tokens we know we don't want - for example, if the first
+        // token is a separator, drop it.
         $taggedTokens = $this->postTokenize($taggedTokens);
 
         // do the heavy lifting
         $span = $this->tokensToSpan($taggedTokens, $options);
 
-        // generate the result and return it, the span, or a guessed time within the span
+        // generate the result and return it, the span, or a guessed time
+        // within the span
         $result = new Horde_Date_Parser_Result($span, $tokens);
         switch ($options['return']) {
         case 'result':
@@ -124,45 +123,82 @@ class Horde_Date_Parser_Locale_Pt extends Horde_Date_Parser_Locale_Base
     }
 
     /**
-	Replaces special characters with non-special equivalents
-	source: http://pt2.php.net/manual/en/function.chr.php#93291
-    */
-	public function normalize_special_characters( $str )
+     * Replaces special characters with non-special equivalents.
+     *
+     * Source: http://pt2.php.net/manual/en/function.chr.php#93291
+     */
+	public function normalize_special_characters($str)
 	{
-	    # Quotes cleanup
-	    $str = ereg_replace( chr(ord("`")), "'", $str );        # `
-	    $str = ereg_replace( chr(ord("´")), "'", $str );        # ´
-	    $str = ereg_replace( chr(ord("„")), ",", $str );        # „
-	    $str = ereg_replace( chr(ord("`")), "'", $str );        # `
-	    $str = ereg_replace( chr(ord("´")), "'", $str );        # ´
-	    $str = ereg_replace( chr(ord("“")), "\"", $str );       # “
-	    $str = ereg_replace( chr(ord("”")), "\"", $str );       # ”
-	    $str = ereg_replace( chr(ord("´")), "'", $str );        # ´
+	    // Quotes cleanup
+	    $str = str_replace(
+            array(
+                chr(ord("`")),
+                chr(ord("´")),
+                chr(ord("„")),
+                chr(ord("`")),
+                chr(ord("´")),
+                chr(ord("“")),
+                chr(ord("”")),
+                chr(ord("´")),
+            ),
+            array(
+                "'",
+                "'",
+                ",",
+                "'",
+                "'",
+                "\"",
+                "\"",
+                "'",
+            ),
+           $str
+        );
 
-	    $unwanted_array = array('Š'=>'S', 'š'=>'s', 'Ž'=>'Z', 'ž'=>'z', 'À'=>'A', 'Á'=>'A', 'Â'=>'A', 'Ã'=>'A', 'Ä'=>'A', 'Å'=>'A', 'Æ'=>'A', 'Ç'=>'C', 'È'=>'E', 'É'=>'E',
-		                        'Ê'=>'E', 'Ë'=>'E', 'Ì'=>'I', 'Í'=>'I', 'Î'=>'I', 'Ï'=>'I', 'Ñ'=>'N', 'Ò'=>'O', 'Ó'=>'O', 'Ô'=>'O', 'Õ'=>'O', 'Ö'=>'O', 'Ø'=>'O', 'Ù'=>'U',
-		                        'Ú'=>'U', 'Û'=>'U', 'Ü'=>'U', 'Ý'=>'Y', 'Þ'=>'B', 'ß'=>'Ss', 'à'=>'a', 'á'=>'a', 'â'=>'a', 'ã'=>'a', 'ä'=>'a', 'å'=>'a', 'æ'=>'a', 'ç'=>'c',
-		                        'è'=>'e', 'é'=>'e', 'ê'=>'e', 'ë'=>'e', 'ì'=>'i', 'í'=>'i', 'î'=>'i', 'ï'=>'i', 'ð'=>'o', 'ñ'=>'n', 'ò'=>'o', 'ó'=>'o', 'ô'=>'o', 'õ'=>'o',
-		                        'ö'=>'o', 'ø'=>'o', 'ù'=>'u', 'ú'=>'u', 'û'=>'u', 'ý'=>'y', 'ý'=>'y', 'þ'=>'b', 'ÿ'=>'y' );
-	    $str = strtr( $str, $unwanted_array );
+	    $unwanted_array = array(
+            'Š'=>'S', 'š'=>'s', 'Ž'=>'Z', 'ž'=>'z', 'À'=>'A', 'Á'=>'A',
+            'Â'=>'A', 'Ã'=>'A', 'Ä'=>'A', 'Å'=>'A', 'Æ'=>'A', 'Ç'=>'C',
+            'È'=>'E', 'É'=>'E', 'Ê'=>'E', 'Ë'=>'E', 'Ì'=>'I', 'Í'=>'I',
+            'Î'=>'I', 'Ï'=>'I', 'Ñ'=>'N', 'Ò'=>'O', 'Ó'=>'O', 'Ô'=>'O',
+            'Õ'=>'O', 'Ö'=>'O', 'Ø'=>'O', 'Ù'=>'U', 'Ú'=>'U', 'Û'=>'U',
+            'Ü'=>'U', 'Ý'=>'Y', 'Þ'=>'B', 'ß'=>'Ss', 'à'=>'a', 'á'=>'a',
+            'â'=>'a', 'ã'=>'a', 'ä'=>'a', 'å'=>'a', 'æ'=>'a', 'ç'=>'c',
+            'è'=>'e', 'é'=>'e', 'ê'=>'e', 'ë'=>'e', 'ì'=>'i', 'í'=>'i',
+            'î'=>'i', 'ï'=>'i', 'ð'=>'o', 'ñ'=>'n', 'ò'=>'o', 'ó'=>'o',
+            'ô'=>'o', 'õ'=>'o', 'ö'=>'o', 'ø'=>'o', 'ù'=>'u', 'ú'=>'u',
+            'û'=>'u', 'ý'=>'y', 'ý'=>'y', 'þ'=>'b', 'ÿ'=>'y'
+        );
+	    $str = strtr($str, $unwanted_array);
 
-	    # Bullets, dashes, and trademarks
-	    $str = ereg_replace( chr(149), "&#8226;", $str );    # bullet •
-	    $str = ereg_replace( chr(150), "&ndash;", $str );    # en dash
-	    $str = ereg_replace( chr(151), "&mdash;", $str );    # em dash
-	    $str = ereg_replace( chr(153), "&#8482;", $str );    # trademark
-	    $str = ereg_replace( chr(169), "&copy;", $str );     # copyright mark
-	    $str = ereg_replace( chr(174), "&reg;", $str );      # registration mark
+	    // Bullets, dashes, and trademarks
+	    $str = str_replace(
+            array(
+                chr(149), # bullet •
+                chr(150), # en dash
+                chr(151), # em dash
+                chr(153), # trademark
+                chr(169), # copyright mark
+                chr(174), # registration mark
+            ),
+            array(
+                '&#8226;',
+                '&ndash;',
+                '&mdash;',
+                '&#8482;',
+                '&copy;', 
+                '&reg;',
+            ),
+            $str
+        );
 
 	    return $str;
 	}
 
 
     /**
-    # Clean up the specified input text by stripping unwanted characters,
-    # converting idioms to their canonical form, converting number words
-    # to numbers (three => 3), and converting ordinal words to numeric
-    # ordinals (third => 3rd)
+     * Clean up the specified input text by stripping unwanted characters,
+     * converting idioms to their canonical form, converting number words to
+     * numbers (three => 3), and converting ordinal words to numeric ordinals
+     * (third => 3rd)
     */
     public function preNormalize($text)
     {
@@ -175,44 +211,77 @@ class Horde_Date_Parser_Locale_Pt extends Horde_Date_Parser_Locale_Base
 		$text = preg_replace('/(?:(?:https?|ftp):\/\/)/', '', $text);
 
 		// composed sentences
-        $text = preg_replace('/\bsegunda[ \-]feira\b/', 'segunda', $text);
-		$text = preg_replace('/\bterca[ \-]feira\b/', 'terca', $text);
-		$text = preg_replace('/\bquarta[ \-]feira\b/', 'quarta', $text);
-		$text = preg_replace('/\bquinta[ \-]feira\b/', 'quinta', $text);
-		$text = preg_replace('/\bsexta[ \-]feira\b/', 'sexta', $text);
-
-		$text = preg_replace('/[\'"\.]/', '', $text);
-		$text = preg_replace('/([\/\-\,\@])/', ' $1 ', $text);
-		$text = preg_replace('/\bhoje\b/', 'this day', $text);
-        $text = preg_replace('/\bamanh[aã]\b/', 'next day', $text);
-		$text = preg_replace('/\bontem\b/', 'last day', $text);
-		$text = preg_replace('/\bfim de semana\b/', 'fds', $text);
-        $text = preg_replace('/\bmeio\s+dia\b/', '12:00', $text);
-        $text = preg_replace('/\bmeia\s+noite\b/', '24:00', $text);
-        $text = preg_replace('/\b(antes|anterior)\b/', 'past', $text);
-        $text = preg_replace('/\b(agora|j[aá])\b/', 'this second', $text);
-        $text = preg_replace('/\b[uú]ltim[oa]\b/', 'last', $text);
-        $text = preg_replace('/\b(?:de|na|durante\s+a|logo(?:\s[aà]|de))\s+(manh[aã]|madrugada)\b/', 'morning', $text);
-        $text = preg_replace('/\b(?:de|[àa]|durante\s+a|logo(?:\s[aà]|de))\s+tarde\b/', 'afternoon', $text);
-        $text = preg_replace('/\b((?:de|[àa]|durante\s+a|logo(?:\s[aà]))\s+noite|(?:ao)\s+anoitecer)\b/', 'this night', $text);
-
+        $text = preg_replace(
+            array(
+                '/\bsegunda[ \-]feira\b/',
+                '/\bterca[ \-]feira\b/',
+                '/\bquarta[ \-]feira\b/',
+                '/\bquinta[ \-]feira\b/',
+                '/\bsexta[ \-]feira\b/', 
+                '/[\'"\.]/',
+                '/([\/\-\,\@])/',
+                '/\bhoje\b/',
+                '/\bamanh[aã]\b/',
+                '/\bontem\b/',
+                '/\bfim de semana\b/',
+                '/\bmeio\s+dia\b/',
+                '/\bmeia\s+noite\b/',
+                '/\b(antes|anterior)\b/',
+                '/\b(agora|j[aá])\b/',
+                '/\b[uú]ltim[oa]\b/',
+                '/\b(?:de|na|durante\s+a|logo(?:\s[aà]|de))\s+(manh[aã]|madrugada)\b/',
+                '/\b(?:de|[àa]|durante\s+a|logo(?:\s[aà]|de))\s+tarde\b/',
+                '/\b((?:de|[àa]|durante\s+a|logo(?:\s[aà]))\s+noite|(?:ao)\s+anoitecer)\b/',
+            ),
+            array(
+                'segunda',
+                'terca',
+                'quarta',
+                'quinta',
+                'sexta',
+                '',
+                ' $1 ',
+                'this day',
+                'next day',
+                'last day',
+                'fds',
+                '12:00',
+                '24:00',
+                'past',
+                'this second',
+                'last',
+                'morning',
+                'afternoon',
+                'this night',
+            ),
+            $text
+        );
+        
 		$text = preg_replace_callback(
 			'/\b([0-1]?[0-9]|2[0-3])(:|,|.)?([0-5][0-9])?\s?(horas?)\b/',
-			create_function(
-				'$matches',
-					'
-					$minute = ($matches[3]!="")? str_pad($matches[3], 2 , "0", STR_PAD_LEFT): "00";
-					$hour = $matches[1];
-					return $hour.":".$minute." oclock";
-					'
-			),
-		$text);
+			function($matches) {
+                $minute = ($matches[3] != '')
+                    ? str_pad($matches[3], 2 , '0', STR_PAD_LEFT)
+                    : '00';
+                $hour = $matches[1];
+                return $hour . ':' . $minute . ' oclock';
+            },
+            $text
+        );
 
-        $text = preg_replace('/\b(horas?|h|hrs?)\b/', ' oclock', $text);
-
-        $text = preg_replace('/\b(depois|ap[oó]s)\b/', 'future', $text);
-
-		$text = preg_replace('/\bdia\b/', '', $text);		// broke parser: redundant, ignore and read from number day
+        $text = preg_replace(
+            array(
+                '/\b(horas?|h|hrs?)\b/',
+                '/\b(depois|ap[oó]s)\b/',
+                '/\bdia\b/',
+            ),
+            array(
+                ' oclock',
+                'future',
+                '', // broke parser: redundant, ignore and read from number day
+            ),
+            $text
+        );
 
         // $text = $this->numericizeNumbers($text);
 
@@ -282,7 +351,7 @@ class Horde_Date_Parser_Locale_Pt extends Horde_Date_Parser_Locale_Base
 				new Horde_Date_Parser_Handler(array(':ordinal_day',  ':separator_at?', ':repeater_month_name', ':separator_at?', 'time?'), 'handle_od_rmn'),
                 new Horde_Date_Parser_Handler(array(':repeater_day_name',  ':separator_at?', ':time?'), 'handle_rdn'),
 				new Horde_Date_Parser_Handler(array(':scalar_day',  ':separator_at?', ':scalar_month', ':separator_at?', ':scalar_year?', 'time?'), 'handle_sd_sm_sy'),
-				new Horde_Date_Parser_Handler(array(':scalar_day',  ':separator_at?', ':repeater_month_name', ':separator_at?', ':scalar_year', ':separator_at?', 'time?'), 'handle_sd_rmn_sy'), 
+				new Horde_Date_Parser_Handler(array(':scalar_day',  ':separator_at?', ':repeater_month_name', ':separator_at?', ':scalar_year', ':separator_at?', 'time?'), 'handle_sd_rmn_sy'),
 				*/
                 new Horde_Date_Parser_Handler(array(':scalar_day', ':separator_slash_or_dash', ':scalar_month', ':separator_slash_or_dash', ':scalar_year', ':separator_at?', 'time?'), 'handle_sd_sm_sy'),
 				new Horde_Date_Parser_Handler(array(':scalar_year', ':separator_slash_or_dash', ':scalar_month', ':separator_slash_or_dash', ':scalar_day', ':separator_at?', 'time?'), 'handle_sy_sm_sd'),
@@ -313,29 +382,10 @@ class Horde_Date_Parser_Locale_Pt extends Horde_Date_Parser_Locale_Base
 
     public function handle_rdn($tokens, $options)
     {
-        $day = $tokens[0]->getTag('repeater_day_name');
-
         try {
-/*
-			if ($day == date('j')) {
-				$dayStart = new Horde_Date(time());
-			} else if ($day < date('j')) {
-				$month = date('m');
-				$year = date('Y');
-				$dayStart = new Horde_Date($year, $month, $day);
-			} else {
-				if (date('m') == 12)) {
-					$month = 1;
-					$year = date('Y')+1;
-				} else {
-					$month = date('m');
-					$year = date('Y');
-				}
-				$dayStart = new Horde_Date($year, $month, $day);
-			}
-*/
-            $dayStart = new Horde_Date(time());
-            return $this->dayOrTime($dayStart, array($tokens[0]), $options);
+            return $this->dayOrTime(
+                new Horde_Date(time()), array($tokens[0]), $options
+            );
         } catch (Exception $e) {
             return null;
         }
@@ -344,13 +394,21 @@ class Horde_Date_Parser_Locale_Pt extends Horde_Date_Parser_Locale_Base
 	// JPC
     public function handle_sd_rmn($tokens, $options)
     {
-		return $this->handle_m_d($tokens[1]->getTag('repeater_month_name'), $tokens[0]->getTag('scalar_day'), array_slice($tokens, 2), $options);
+		return $this->handle_m_d(
+            $tokens[1]->getTag('repeater_month_name'),
+            $tokens[0]->getTag('scalar_day'),
+            array_slice($tokens, 2),
+            $options
+        );
 	}
 
     public function handle_od_rmn($tokens, $options)
 	{
-	    return $this->handle_m_d($tokens[1]->getTag('repeater_month_name'), $tokens[0]->getTag('ordinal_day'), array_slice($tokens, 2), $options);
+	    return $this->handle_m_d(
+            $tokens[1]->getTag('repeater_month_name'),
+            $tokens[0]->getTag('ordinal_day'),
+            array_slice($tokens, 2),
+            $options
+        );
 	}
-
-
 }
